┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphinview.h
diff options
context:
space:
mode:
authorPeter Penz <[email protected]>2008-01-21 14:16:31 +0000
committerPeter Penz <[email protected]>2008-01-21 14:16:31 +0000
commit1daef0dc52a18b03e2bc5b4ce85944356b6b5da3 (patch)
tree7598d62b33b41758e83daaa035d29de3c8a03a9b /src/dolphinview.h
parent37d4fa2d15d9a629298b1c4f93a50db5c2d607b2 (diff)
Cleanup: let the DolphinView be aware about the used action collection. This will allow us cleaning up some code in DolphinMainWindow and will make it easier sharing code with DolphinPart.
CCMAIL: [email protected] svn path=/trunk/KDE/kdebase/apps/; revision=764347
Diffstat (limited to 'src/dolphinview.h')
-rw-r--r--src/dolphinview.h29
1 files changed, 19 insertions, 10 deletions
diff --git a/src/dolphinview.h b/src/dolphinview.h
index fa5b18471..b42f57007 100644
--- a/src/dolphinview.h
+++ b/src/dolphinview.h
@@ -47,6 +47,7 @@ class DolphinModel;
class DolphinSortFilterProxyModel;
class IconManager;
class KAction;
+class KActionCollection;
class KDirLister;
class KFileItemDelegate;
class KUrl;
@@ -116,21 +117,23 @@ public:
};
/**
* @param parent Parent widget of the view.
* @param url Specifies the content which should be shown.
* @param dirLister Used directory lister. The lister is not owned
* by the view and won't get deleted.
* @param dolphinModel Used directory model. The model is not owned
* by the view and won't get deleted.
* @param proxyModel Used proxy model which specifies the sorting. The
* model is not owned by the view and won't get
* deleted.
*/
DolphinView(QWidget* parent,
const KUrl& url,
KDirLister* dirLister,
DolphinModel* dolphinModel,
- DolphinSortFilterProxyModel* proxyModel);
+ DolphinSortFilterProxyModel* proxyModel,
+ KActionCollection* actionCollection);
virtual ~DolphinView();
@@ -591,6 +594,12 @@ private slots:
*/
void slotDeleteFileFinished(KJob* job);
+ /**
+ * Opens the dialog for creating a directory. Is connected
+ * with the key shortcut for "new directory" (F10).
+ */
+ void createDir();
+
private:
void loadDirectory(const KUrl& url, bool reload = false);
@@ -116,21 +117,23 @@ public:
};
/**
- * @param parent Parent widget of the view.
- * @param url Specifies the content which should be shown.
- * @param dirLister Used directory lister. The lister is not owned
- * by the view and won't get deleted.
- * @param dolphinModel Used directory model. The model is not owned
- * by the view and won't get deleted.
- * @param proxyModel Used proxy model which specifies the sorting. The
- * model is not owned by the view and won't get
- * deleted.
+ * @param parent Parent widget of the view.
+ * @param url Specifies the content which should be shown.
+ * @param dirLister Used directory lister. The lister is not owned
+ * by the view and won't get deleted.
+ * @param dolphinModel Used directory model. The model is not owned
+ * by the view and won't get deleted.
+ * @param proxyModel Used proxy model which specifies the sorting. The
+ * model is not owned by the view and won't get
+ * deleted.
+ * @param actionCollection Action collection which contains the menu actions.
*/
DolphinView(QWidget* parent,